mock_exec

package
v0.2.17 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 6, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package mock_exec is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockCmd

type MockCmd struct {
	// contains filtered or unexported fields
}

MockCmd is a mock of Cmd interface.

func NewMockCmd

func NewMockCmd(ctrl *gomock.Controller) *MockCmd

NewMockCmd creates a new mock instance.

func (*MockCmd) Args

func (m *MockCmd) Args() []string

Args mocks base method.

func (*MockCmd) CombinedOutput

func (m *MockCmd) CombinedOutput() ([]byte, error)

CombinedOutput mocks base method.

func (*MockCmd) Dir

func (m *MockCmd) Dir() string

Dir mocks base method.

func (*MockCmd) EXPECT

func (m *MockCmd) EXPECT() *MockCmdMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockCmd) Env

func (m *MockCmd) Env() []string

Env mocks base method.

func (*MockCmd) Environ

func (m *MockCmd) Environ() []string

Environ mocks base method.

func (*MockCmd) Output

func (m *MockCmd) Output() ([]byte, error)

Output mocks base method.

func (*MockCmd) Path

func (m *MockCmd) Path() string

Path mocks base method.

func (*MockCmd) Process

func (m *MockCmd) Process() *os.Process

Process mocks base method.

func (*MockCmd) ProcessState

func (m *MockCmd) ProcessState() *os.ProcessState

ProcessState mocks base method.

func (*MockCmd) Run

func (m *MockCmd) Run() error

Run mocks base method.

func (*MockCmd) Start

func (m *MockCmd) Start() error

Start mocks base method.

func (*MockCmd) Stderr

func (m *MockCmd) Stderr() io.Writer

Stderr mocks base method.

func (*MockCmd) StderrPipe

func (m *MockCmd) StderrPipe() (io.ReadCloser, error)

StderrPipe mocks base method.

func (*MockCmd) Stdin

func (m *MockCmd) Stdin() io.Reader

Stdin mocks base method.

func (*MockCmd) StdinPipe

func (m *MockCmd) StdinPipe() (io.WriteCloser, error)

StdinPipe mocks base method.

func (*MockCmd) Stdout

func (m *MockCmd) Stdout() io.Writer

Stdout mocks base method.

func (*MockCmd) StdoutPipe

func (m *MockCmd) StdoutPipe() (io.ReadCloser, error)

StdoutPipe mocks base method.

func (*MockCmd) String

func (m *MockCmd) String() string

String mocks base method.

func (*MockCmd) Wait

func (m *MockCmd) Wait() error

Wait mocks base method.

type MockCmdMockRecorder

type MockCmdMockRecorder struct {
	// contains filtered or unexported fields
}

MockCmdMockRecorder is the mock recorder for MockCmd.

func (*MockCmdMockRecorder) Args

func (mr *MockCmdMockRecorder) Args() *gomock.Call

Args indicates an expected call of Args.

func (*MockCmdMockRecorder) CombinedOutput

func (mr *MockCmdMockRecorder) CombinedOutput() *gomock.Call

CombinedOutput indicates an expected call of CombinedOutput.

func (*MockCmdMockRecorder) Dir

func (mr *MockCmdMockRecorder) Dir() *gomock.Call

Dir indicates an expected call of Dir.

func (*MockCmdMockRecorder) Env

func (mr *MockCmdMockRecorder) Env() *gomock.Call

Env indicates an expected call of Env.

func (*MockCmdMockRecorder) Environ

func (mr *MockCmdMockRecorder) Environ() *gomock.Call

Environ indicates an expected call of Environ.

func (*MockCmdMockRecorder) Output

func (mr *MockCmdMockRecorder) Output() *gomock.Call

Output indicates an expected call of Output.

func (*MockCmdMockRecorder) Path

func (mr *MockCmdMockRecorder) Path() *gomock.Call

Path indicates an expected call of Path.

func (*MockCmdMockRecorder) Process

func (mr *MockCmdMockRecorder) Process() *gomock.Call

Process indicates an expected call of Process.

func (*MockCmdMockRecorder) ProcessState

func (mr *MockCmdMockRecorder) ProcessState() *gomock.Call

ProcessState indicates an expected call of ProcessState.

func (*MockCmdMockRecorder) Run

func (mr *MockCmdMockRecorder) Run() *gomock.Call

Run indicates an expected call of Run.

func (*MockCmdMockRecorder) Start

func (mr *MockCmdMockRecorder) Start() *gomock.Call

Start indicates an expected call of Start.

func (*MockCmdMockRecorder) Stderr

func (mr *MockCmdMockRecorder) Stderr() *gomock.Call

Stderr indicates an expected call of Stderr.

func (*MockCmdMockRecorder) StderrPipe

func (mr *MockCmdMockRecorder) StderrPipe() *gomock.Call

StderrPipe indicates an expected call of StderrPipe.

func (*MockCmdMockRecorder) Stdin

func (mr *MockCmdMockRecorder) Stdin() *gomock.Call

Stdin indicates an expected call of Stdin.

func (*MockCmdMockRecorder) StdinPipe

func (mr *MockCmdMockRecorder) StdinPipe() *gomock.Call

StdinPipe indicates an expected call of StdinPipe.

func (*MockCmdMockRecorder) Stdout

func (mr *MockCmdMockRecorder) Stdout() *gomock.Call

Stdout indicates an expected call of Stdout.

func (*MockCmdMockRecorder) StdoutPipe

func (mr *MockCmdMockRecorder) StdoutPipe() *gomock.Call

StdoutPipe indicates an expected call of StdoutPipe.

func (*MockCmdMockRecorder) String

func (mr *MockCmdMockRecorder) String() *gomock.Call

String indicates an expected call of String.

func (*MockCmdMockRecorder) Wait

func (mr *MockCmdMockRecorder) Wait() *gomock.Call

Wait indicates an expected call of Wait.

type MockExec

type MockExec struct {
	// contains filtered or unexported fields
}

MockExec is a mock of Exec interface.

func NewMockExec

func NewMockExec(ctrl *gomock.Controller) *MockExec

NewMockExec creates a new mock instance.

func (*MockExec) EXPECT

func (m *MockExec) EXPECT() *MockExecMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockExec) LookPath

func (m *MockExec) LookPath(arg0 string) (string, error)

LookPath mocks base method.

func (*MockExec) NewCommand

func (m *MockExec) NewCommand(arg0 string, arg1 ...exec.CommandOption) exec.Cmd

NewCommand mocks base method.

type MockExecMockRecorder

type MockExecMockRecorder struct {
	// contains filtered or unexported fields
}

MockExecMockRecorder is the mock recorder for MockExec.

func (*MockExecMockRecorder) LookPath

func (mr *MockExecMockRecorder) LookPath(arg0 any) *gomock.Call

LookPath indicates an expected call of LookPath.

func (*MockExecMockRecorder) NewCommand

func (mr *MockExecMockRecorder) NewCommand(arg0 any, arg1 ...any) *gomock.Call

NewCommand indicates an expected call of NewCommand.

Jump to