Documentation
¶
Overview ¶
Package mock_json is a generated GoMock package.
Index ¶
- type MockDecoder
- func (m *MockDecoder) Buffered() io.Reader
- func (m *MockDecoder) Decode(v any) error
- func (m *MockDecoder) EXPECT() *MockDecoderMockRecorder
- func (m *MockDecoder) InputOffset() int64
- func (m *MockDecoder) More() bool
- func (m *MockDecoder) Nub() *json.Decoder
- func (m *MockDecoder) Token() (json.Token, error)
- type MockDecoderMockRecorder
- func (mr *MockDecoderMockRecorder) Buffered() *gomock.Call
- func (mr *MockDecoderMockRecorder) Decode(v any) *gomock.Call
- func (mr *MockDecoderMockRecorder) InputOffset() *gomock.Call
- func (mr *MockDecoderMockRecorder) More() *gomock.Call
- func (mr *MockDecoderMockRecorder) Nub() *gomock.Call
- func (mr *MockDecoderMockRecorder) Token() *gomock.Call
- type MockEncoder
- type MockEncoderMockRecorder
- type MockJSON
- func (m *MockJSON) Compact(dst *bytes.Buffer, src []byte) error
- func (m *MockJSON) EXPECT() *MockJSONMockRecorder
- func (m *MockJSON) HTMLEscape(dst *bytes.Buffer, src []byte)
- func (m *MockJSON) Indent(dst *bytes.Buffer, src []byte, prefix, indent string) error
- func (m *MockJSON) Marshal(v any) ([]byte, error)
- func (m *MockJSON) MarshalIndent(v any, prefix, indent string) ([]byte, error)
- func (m *MockJSON) NewDecoder(r io.Reader, options ...json0.DecoderOption) json0.Decoder
- func (m *MockJSON) NewEncoder(w io.Writer, options ...json0.EncoderOption) json0.Encoder
- func (m *MockJSON) Unmarshal(data []byte, v any) error
- func (m *MockJSON) Valid(data []byte) bool
- type MockJSONMockRecorder
- func (mr *MockJSONMockRecorder) Compact(dst, src any) *gomock.Call
- func (mr *MockJSONMockRecorder) HTMLEscape(dst, src any) *gomock.Call
- func (mr *MockJSONMockRecorder) Indent(dst, src, prefix, indent any) *gomock.Call
- func (mr *MockJSONMockRecorder) Marshal(v any) *gomock.Call
- func (mr *MockJSONMockRecorder) MarshalIndent(v, prefix, indent any) *gomock.Call
- func (mr *MockJSONMockRecorder) NewDecoder(r any, options ...any) *gomock.Call
- func (mr *MockJSONMockRecorder) NewEncoder(w any, options ...any) *gomock.Call
- func (mr *MockJSONMockRecorder) Unmarshal(data, v any) *gomock.Call
- func (mr *MockJSONMockRecorder) Valid(data any) *gomock.Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockDecoder ¶
type MockDecoder struct {
// contains filtered or unexported fields
}
MockDecoder is a mock of Decoder interface.
func NewMockDecoder ¶
func NewMockDecoder(ctrl *gomock.Controller) *MockDecoder
NewMockDecoder creates a new mock instance.
func (*MockDecoder) Buffered ¶
func (m *MockDecoder) Buffered() io.Reader
Buffered mocks base method.
func (*MockDecoder) EXPECT ¶
func (m *MockDecoder) EXPECT() *MockDecoderMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockDecoder) InputOffset ¶
func (m *MockDecoder) InputOffset() int64
InputOffset mocks base method.
type MockDecoderMockRecorder ¶
type MockDecoderMockRecorder struct {
// contains filtered or unexported fields
}
MockDecoderMockRecorder is the mock recorder for MockDecoder.
func (*MockDecoderMockRecorder) Buffered ¶
func (mr *MockDecoderMockRecorder) Buffered() *gomock.Call
Buffered indicates an expected call of Buffered.
func (*MockDecoderMockRecorder) Decode ¶
func (mr *MockDecoderMockRecorder) Decode(v any) *gomock.Call
Decode indicates an expected call of Decode.
func (*MockDecoderMockRecorder) InputOffset ¶
func (mr *MockDecoderMockRecorder) InputOffset() *gomock.Call
InputOffset indicates an expected call of InputOffset.
func (*MockDecoderMockRecorder) More ¶
func (mr *MockDecoderMockRecorder) More() *gomock.Call
More indicates an expected call of More.
func (*MockDecoderMockRecorder) Nub ¶
func (mr *MockDecoderMockRecorder) Nub() *gomock.Call
Nub indicates an expected call of Nub.
func (*MockDecoderMockRecorder) Token ¶
func (mr *MockDecoderMockRecorder) Token() *gomock.Call
Token indicates an expected call of Token.
type MockEncoder ¶
type MockEncoder struct {
// contains filtered or unexported fields
}
MockEncoder is a mock of Encoder interface.
func NewMockEncoder ¶
func NewMockEncoder(ctrl *gomock.Controller) *MockEncoder
NewMockEncoder creates a new mock instance.
func (*MockEncoder) EXPECT ¶
func (m *MockEncoder) EXPECT() *MockEncoderMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockEncoder) SetEscapeHTML ¶
func (m *MockEncoder) SetEscapeHTML(on bool)
SetEscapeHTML mocks base method.
func (*MockEncoder) SetIndent ¶
func (m *MockEncoder) SetIndent(prefix, indent string)
SetIndent mocks base method.
type MockEncoderMockRecorder ¶
type MockEncoderMockRecorder struct {
// contains filtered or unexported fields
}
MockEncoderMockRecorder is the mock recorder for MockEncoder.
func (*MockEncoderMockRecorder) Encode ¶
func (mr *MockEncoderMockRecorder) Encode(v any) *gomock.Call
Encode indicates an expected call of Encode.
func (*MockEncoderMockRecorder) Nub ¶
func (mr *MockEncoderMockRecorder) Nub() *gomock.Call
Nub indicates an expected call of Nub.
func (*MockEncoderMockRecorder) SetEscapeHTML ¶
func (mr *MockEncoderMockRecorder) SetEscapeHTML(on any) *gomock.Call
SetEscapeHTML indicates an expected call of SetEscapeHTML.
type MockJSON ¶
type MockJSON struct {
// contains filtered or unexported fields
}
MockJSON is a mock of JSON interface.
func NewMockJSON ¶
func NewMockJSON(ctrl *gomock.Controller) *MockJSON
NewMockJSON creates a new mock instance.
func (*MockJSON) EXPECT ¶
func (m *MockJSON) EXPECT() *MockJSONMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockJSON) HTMLEscape ¶
HTMLEscape mocks base method.
func (*MockJSON) MarshalIndent ¶
MarshalIndent mocks base method.
func (*MockJSON) NewDecoder ¶
NewDecoder mocks base method.
func (*MockJSON) NewEncoder ¶
NewEncoder mocks base method.
type MockJSONMockRecorder ¶
type MockJSONMockRecorder struct {
// contains filtered or unexported fields
}
MockJSONMockRecorder is the mock recorder for MockJSON.
func (*MockJSONMockRecorder) Compact ¶
func (mr *MockJSONMockRecorder) Compact(dst, src any) *gomock.Call
Compact indicates an expected call of Compact.
func (*MockJSONMockRecorder) HTMLEscape ¶
func (mr *MockJSONMockRecorder) HTMLEscape(dst, src any) *gomock.Call
HTMLEscape indicates an expected call of HTMLEscape.
func (*MockJSONMockRecorder) Indent ¶
func (mr *MockJSONMockRecorder) Indent(dst, src, prefix, indent any) *gomock.Call
Indent indicates an expected call of Indent.
func (*MockJSONMockRecorder) Marshal ¶
func (mr *MockJSONMockRecorder) Marshal(v any) *gomock.Call
Marshal indicates an expected call of Marshal.
func (*MockJSONMockRecorder) MarshalIndent ¶
func (mr *MockJSONMockRecorder) MarshalIndent(v, prefix, indent any) *gomock.Call
MarshalIndent indicates an expected call of MarshalIndent.
func (*MockJSONMockRecorder) NewDecoder ¶
func (mr *MockJSONMockRecorder) NewDecoder(r any, options ...any) *gomock.Call
NewDecoder indicates an expected call of NewDecoder.
func (*MockJSONMockRecorder) NewEncoder ¶
func (mr *MockJSONMockRecorder) NewEncoder(w any, options ...any) *gomock.Call
NewEncoder indicates an expected call of NewEncoder.